==> tuia-commercial-center-api-0.0.4-20190718.040007-11-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/user/BizUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.user;

import java.io.Serializable;
import java.util.Date;

public class BizUserDto implements Serializable {

    private static final long serialVersionUID = -6632956374371303940L;

    /*主键ID*/
    private Long id;

    /*设备ID*/
    private String deviceId;

    /*媒体ID*/
    private Long appId;

    /*活动用户ID*/
    private Long consumerId;

    /*现金*/
    private Long cash;

    /*冻结的预算*/
    private Long frozenBudget;

    /*提现次数*/
    private Integer withdrawTimes;

    /*最近提现时间*/
    private Date lastWithdrawTime;

    private Date gmtCreate;

    private Date gmtModified;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getCash() {
        return cash;
    }

    public void setCash(Long cash) {
        this.cash = cash;
    }

    public Long getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Long frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Integer getWithdrawTimes() {
        return withdrawTimes;
    }

    public void setWithdrawTimes(Integer withdrawTimes) {
        this.withdrawTimes = withdrawTimes;
    }

    public Date getLastWithdrawTime() {
        return lastWithdrawTime;
    }

    public void setLastWithdrawTime(Date lastWithdrawTime) {
        this.lastWithdrawTime = lastWithdrawTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }


}

==> tuia-commercial-center-api-1.0.3-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/user/BizUserDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.user;

import java.io.Serializable;
import java.util.Date;

public class BizUserDto implements Serializable {

    private static final long serialVersionUID = -6632956374371303940L;

    /*主键ID*/
    private Long id;

    /*设备ID*/
    private String deviceId;

    /*媒体ID*/
    private Long appId;

    /*活动用户ID*/
    private Long consumerId;

    /*现金*/
    private Long cash;

    /*冻结的预算*/
    private Long frozenBudget;

    /*提现次数*/
    private Integer withdrawTimes;

    /*最近提现时间*/
    private Date lastWithdrawTime;

    private Date gmtCreate;

    private Date gmtModified;

    private String mediaUserId;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getDeviceId() {
        return deviceId;
    }

    public void setDeviceId(String deviceId) {
        this.deviceId = deviceId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getConsumerId() {
        return consumerId;
    }

    public void setConsumerId(Long consumerId) {
        this.consumerId = consumerId;
    }

    public Long getCash() {
        return cash;
    }

    public void setCash(Long cash) {
        this.cash = cash;
    }

    public Long getFrozenBudget() {
        return frozenBudget;
    }

    public void setFrozenBudget(Long frozenBudget) {
        this.frozenBudget = frozenBudget;
    }

    public Integer getWithdrawTimes() {
        return withdrawTimes;
    }

    public void setWithdrawTimes(Integer withdrawTimes) {
        this.withdrawTimes = withdrawTimes;
    }

    public Date getLastWithdrawTime() {
        return lastWithdrawTime;
    }

    public void setLastWithdrawTime(Date lastWithdrawTime) {
        this.lastWithdrawTime = lastWithdrawTime;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public String getMediaUserId() {
        return mediaUserId;
    }

    public void setMediaUserId(String mediaUserId) {
        this.mediaUserId = mediaUserId;
    }

}
